"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.handleFocusStateOnDrag = exports.default = exports.AcceptedFileDecorator = void 0;

var _react = _interopRequireDefault(require("react"));

var _propTypes = _interopRequireDefault(require("prop-types"));

var _AttachFile = _interopRequireDefault(require("@material-ui/icons/AttachFile"));

var _q3UiHelpers = require("q3-ui-helpers");

var _reactDropzone = require("react-dropzone");

var _q3UiLocale = require("q3-ui-locale");

var _useStyle = _interopRequireDefault(require("./useStyle"));

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

function _extends() { _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; }; return _extends.apply(this, arguments); }

const DROPPER_ID = 'dropper';

const joinFilePaths = (a = []) => {
  const out = _q3UiHelpers.array.is(a).filter(Boolean).join('/').replace(/\/+/g, '/');

  return out.startsWith('/') ? out.substr(1) : out;
};

class AcceptedFileDecorator {
  constructor(files) {
    this.data = _q3UiHelpers.array.is(files);
  }

  set directory(name) {
    this.data.forEach(item => {
      // eslint-disable-next-line
      item.relativePath = joinFilePaths([name, item.name]);
    });
    return this;
  }

  withErrors() {
    return this.data.map(item => {
      // eslint-disable-next-line
      item.error = true;
      return item;
    });
  }

}

exports.AcceptedFileDecorator = AcceptedFileDecorator;

const handleFocusStateOnDrag = isDragActive => {
  if (_q3UiHelpers.browser.isBrowserReady()) _q3UiHelpers.object.invokeInSafely(document.getElementById(DROPPER_ID), isDragActive ? 'focus' : 'blur');
};

exports.handleFocusStateOnDrag = handleFocusStateOnDrag;

const Drop = ({
  children,
  customizer,
  onDrop,
  previewComponent,
  root,
  ...rest
}) => {
  const {
    container,
    icon
  } = (0, _useStyle.default)();
  const {
    t
  } = (0, _q3UiLocale.useTranslation)('descriptions');

  const [pendingFiles, setPendingFiles] = _react.default.useState([]);

  const onDropHandler = _react.default.useCallback(acceptedFiles => {
    const formData = new FormData();
    const fs = new AcceptedFileDecorator(acceptedFiles);

    const handleError = () => setPendingFiles(fs.withErrors());

    fs.directory = root;
    fs.data.forEach(item => {
      formData.append(customizer ? customizer(item.relativePath) : item.relativePath, item);
    });

    try {
      setPendingFiles(fs.data);
      return onDrop(formData).then(() => {
        setPendingFiles([]);
      }).catch(handleError);
    } catch (e) {
      // should only run if onDrop is undefined
      return handleError();
    }
  }, [root]);

  const {
    getRootProps,
    getInputProps,
    isDragActive
  } = (0, _reactDropzone.useDropzone)({
    onDrop: onDropHandler,
    ...rest
  });

  const getDropperHandlers = () => ({
    id: DROPPER_ID,
    className: container,
    ...getRootProps()
  });

  _react.default.useEffect(() => {
    handleFocusStateOnDrag(isDragActive);
  }, [isDragActive]);

  return /*#__PURE__*/_react.default.createElement(_react.default.Fragment, null, /*#__PURE__*/_react.default.createElement("div", _extends({
    style: {
      marginBottom: '1rem'
    }
  }, getDropperHandlers()), /*#__PURE__*/_react.default.createElement("input", getInputProps()), previewComponent || /*#__PURE__*/_react.default.createElement(_react.default.Fragment, null, /*#__PURE__*/_react.default.createElement(_AttachFile.default, {
    className: icon
  }), t('clickOrDrop'), ' ')), children(pendingFiles));
};

Drop.defaultProps = {
  root: '',
  customizer: undefined,
  previewComponent: null
};
Drop.propTypes = {
  children: _propTypes.default.func.isRequired,
  customizer: _propTypes.default.func,
  onDrop: _propTypes.default.instanceOf(Promise).isRequired,
  previewComponent: _propTypes.default.node,
  root: _propTypes.default.string
};
var _default = Drop;
exports.default = _default;