"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.makeDirectories = exports.default = void 0;

var _react = _interopRequireDefault(require("react"));

var _propTypes = _interopRequireDefault(require("prop-types"));

var _lodash = require("lodash");

var _q3UiHelpers = require("q3-ui-helpers");

var _alphabetizeObjectKeys = _interopRequireDefault(require("alphabetize-object-keys"));

var _Box = _interopRequireDefault(require("@material-ui/core/Box"));

var _Grid = _interopRequireDefault(require("@material-ui/core/Grid"));

var _FileListBreadcrumbs = _interopRequireDefault(require("../FileListBreadcrumbs"));

var _FileListMake = _interopRequireDefault(require("../FileListMake"));

var _File = _interopRequireDefault(require("../File"));

var _Drop = _interopRequireDefault(require("../Drop"));

var _FileName = _interopRequireDefault(require("../FileName"));

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

function _extends() { _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; }; return _extends.apply(this, arguments); }

const customizer = (objValue, srcValue) => {
  if (Array.isArray(objValue)) return objValue.concat(srcValue);
  return undefined;
};

const getPath = filename => {
  const dir = filename.split('/');
  dir.pop();
  dir.push('default');
  return dir.join('.');
};

const removeFileExtension = filename => filename ? filename.substring(0, filename.lastIndexOf('.')) || filename : '';

const makeDirectories = (a = []) => a.map(next => {
  return (0, _lodash.setWith)({}, // cannot use regular set in case there are dirs with numbers
  // otherwise, it creates an array instead
  getPath(removeFileExtension(next.relativePath)), [next], Object);
}).reduce((acc, next) => {
  return (0, _lodash.mergeWith)(acc, next, customizer);
}, {});

exports.makeDirectories = makeDirectories;

const FileList = ({
  files,
  ...props
}) => {
  const [dir, setDir] = _react.default.useState({
    data: {},
    path: []
  });

  const getFilesForActivePath = _react.default.useCallback(data => {
    const structuredFiles = makeDirectories(data);
    const {
      path = []
    } = dir;
    return _q3UiHelpers.array.hasLength(path) ? (0, _lodash.get)(structuredFiles, path, {}) : structuredFiles;
  }, [dir]);

  _react.default.useEffect(() => {
    setDir(prevState => ({ ...prevState,
      data: getFilesForActivePath(files)
    }));
  }, [files]);

  const renderFile = (file, i) => /*#__PURE__*/_react.default.createElement(_File.default, _extends({}, props, file, {
    key: i // cannot deconstruct properties of the File Api
    // so we must explicitly assign here
    ,
    error: file.error,
    name: file.name,
    size: file.size,
    url: file.url
  }));

  const renderDirectoryUploadSurface = (listItems = [], children) => /*#__PURE__*/_react.default.createElement(_Drop.default, _extends({}, props, {
    root: dir.path.join('/')
  }), pending => /*#__PURE__*/_react.default.createElement(_react.default.Fragment, null, children, [...pending, ...listItems].map(renderFile)));

  return /*#__PURE__*/_react.default.createElement(_Box.default, {
    p: 1
  }, /*#__PURE__*/_react.default.createElement(_Grid.default, {
    alignItems: "center",
    justify: "space-between",
    container: true
  }, /*#__PURE__*/_react.default.createElement(_Grid.default, {
    item: true
  }, /*#__PURE__*/_react.default.createElement(_FileListBreadcrumbs.default, {
    getFilesForActivePath: getFilesForActivePath,
    files: makeDirectories(files),
    setState: setDir,
    state: dir
  })), /*#__PURE__*/_react.default.createElement(_Grid.default, {
    item: true
  }, /*#__PURE__*/_react.default.createElement(_FileListMake.default, {
    setState: setDir,
    state: dir
  }))), renderDirectoryUploadSurface(dir.data.default, Object.keys((0, _alphabetizeObjectKeys.default)(dir.data)).map(name => name !== 'default' ? /*#__PURE__*/_react.default.createElement(_FileName.default, {
    name: name,
    onClick: () => {
      setDir(({
        data,
        path
      }) => ({
        data: data[name],
        path: path.concat(name)
      }));
    }
  }) : null)));
};

FileList.defaultProps = {
  files: []
};
FileList.propTypes = {
  /**
   * Files will sort into directories automatically based on the file name.
   * For instance, "foo/bar.csv" will only be available for download in the child directory.
   */
  files: _propTypes.default.arrayOf(_propTypes.default.shape({
    name: _propTypes.default.string,
    url: _propTypes.default.string
  }))
};
var _default = FileList;
exports.default = _default;