"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = void 0;

var _react = _interopRequireDefault(require("react"));

var _propTypes = _interopRequireDefault(require("prop-types"));

var _Avatar = _interopRequireDefault(require("@material-ui/core/Avatar"));

var _Grid = _interopRequireDefault(require("@material-ui/core/Grid"));

var _CircularProgress = _interopRequireDefault(require("@material-ui/core/CircularProgress"));

var _popover = _interopRequireDefault(require("q3-ui/lib/popover"));

var _useStyle = _interopRequireDefault(require("./useStyle"));

var _FileExtensions = _interopRequireDefault(require("../FileExtensions"));

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

const FileName = ({
  name,
  url,
  onClick,
  loading
}) => {
  const [isTruncated, setIsTruncated] = _react.default.useState(false);

  const [, ext] = name.split('.');
  const cls = (0, _useStyle.default)();

  const make = (el, args = {}) => /*#__PURE__*/_react.default.createElement(el, {
    className: cls.link,
    ...args
  }, name);

  const renderer = () => {
    if (url) return make('a', {
      target: '_blank',
      download: true,
      href: url
    });
    if (onClick) return make('button', {
      type: 'button',
      onClick
    });
    return make('span');
  };

  const renderTooltip = predicate => predicate ? /*#__PURE__*/_react.default.createElement(_popover.default, {
    popoverChildren: name
  }, renderer()) : renderer();

  const ref = _react.default.useRef();

  const checkTruncate = () => setIsTruncated(ref.current.offsetWidth < ref.current.scrollWidth);

  _react.default.useEffect(() => {
    checkTruncate();
    window.addEventListener('resize', checkTruncate);
    return () => {
      window.removeEventListener('resize', checkTruncate);
    };
  }, []);

  return /*#__PURE__*/_react.default.createElement(_Grid.default, {
    container: true,
    alignItems: "center",
    className: cls.root
  }, /*#__PURE__*/_react.default.createElement(_Grid.default, {
    item: true
  }, /*#__PURE__*/_react.default.createElement(_Avatar.default, {
    style: {
      backgroundColor: 'transparent',
      color: _FileExtensions.default.getColor(ext)
    }
  }, loading && /*#__PURE__*/_react.default.createElement(_CircularProgress.default, {
    className: cls.cover
  }), _FileExtensions.default.getIcon(ext))), /*#__PURE__*/_react.default.createElement(_Grid.default, {
    item: true,
    className: cls.truncate,
    ref: ref
  }, renderTooltip(isTruncated)));
};

FileName.propTypes = {
  onClick: _propTypes.default.func,
  name: _propTypes.default.string.isRequired,
  url: _propTypes.default.string,
  loading: _propTypes.default.bool
};
FileName.defaultProps = {
  loading: false,
  onClick: null,
  url: ''
};
var _default = FileName;
exports.default = _default;