"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = exports.FileUploadStatus = exports.FileUploadPreview = void 0;

var _react = _interopRequireDefault(require("react"));

var _propTypes = _interopRequireDefault(require("prop-types"));

var _q3UiHelpers = require("q3-ui-helpers");

var _q3UiLocale = require("q3-ui-locale");

var _Button = _interopRequireDefault(require("@material-ui/core/Button"));

var _PhotoCamera = _interopRequireDefault(require("@material-ui/icons/PhotoCamera"));

var _Box = _interopRequireDefault(require("@material-ui/core/Box"));

var _Drop = _interopRequireDefault(require("../Drop"));

var _useStyle = _interopRequireDefault(require("./useStyle"));

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

function _extends() { _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; }; return _extends.apply(this, arguments); }

const FileUploadPreview = ({
  src
}) => {
  const {
    t
  } = (0, _q3UiLocale.useTranslation)('labels');
  const cls = (0, _useStyle.default)();
  return /*#__PURE__*/_react.default.createElement(_Box.default, {
    className: cls.previewContainer
  }, src ? /*#__PURE__*/_react.default.createElement("img", {
    alt: t('imageThumbnailPreview'),
    className: cls.fit,
    src: src
  }) : /*#__PURE__*/_react.default.createElement(_PhotoCamera.default, {
    className: cls.fit
  }));
};

exports.FileUploadPreview = FileUploadPreview;
FileUploadPreview.defaultProps = {
  src: ''
};
FileUploadPreview.propTypes = {
  src: _propTypes.default.string
};

const FileUploadStatus = ({
  file,
  onDelete
}) => {
  const {
    t
  } = (0, _q3UiLocale.useTranslation)('labels');
  const cls = (0, _useStyle.default)();
  if (!file) return t('clickToSetPhoto');
  if (file.error) return t('photoFailedToUpload');
  if (file.url) return /*#__PURE__*/_react.default.createElement(_Box.default, {
    mt: -1
  }, /*#__PURE__*/_react.default.createElement(_Button.default, {
    id: "q3-photo-remove",
    type: "button",
    onClick: onDelete,
    className: cls.danger,
    fullWidth: true
  }, t('unsetPhoto')));
  return t('uploadingPhoto');
};

exports.FileUploadStatus = FileUploadStatus;
FileUploadStatus.defaultProps = {
  file: null
};
FileUploadStatus.propTypes = {
  file: _propTypes.default.shape({
    url: _propTypes.default.string,
    error: _propTypes.default.bool
  }),
  onDelete: _propTypes.default.func.isRequired
};

const PhotoUpload = ({
  src,
  onDelete,
  ...etc
}) => {
  const [previewUrl, setPreviewUrl] = _react.default.useState();

  _react.default.useEffect(() => {
    setPreviewUrl(src);
  }, [src]);

  return /*#__PURE__*/_react.default.createElement(_Drop.default, _extends({}, etc, {
    multiple: false,
    accept: ".png,.jpg,.jpeg,.svg,.jfif",
    previewComponent: /*#__PURE__*/_react.default.createElement(FileUploadPreview, {
      src: previewUrl
    })
  }), ([file]) => {
    _q3UiHelpers.browser.getFileThumbnail(file, (err, previewSrc) => {
      if (src) setPreviewUrl(previewSrc);
    }); // allows us to "fake" the existing file blob


    return /*#__PURE__*/_react.default.createElement(FileUploadStatus, {
      file: file || {
        url: src
      },
      onDelete: onDelete
    });
  });
};

PhotoUpload.defaultProps = {
  src: ''
};
PhotoUpload.propTypes = {
  src: _propTypes.default.string,
  onDelete: _propTypes.default.func.isRequired
};
var _default = PhotoUpload;
exports.default = _default;